@@ -1,6 +1,5 @@
 """Specialized instance representations."""
 
-import hashlib
 import logging
 from typing import Dict as _Dict, Tuple as _Tuple, Union
 
@@ -24,6 +23,17 @@ def _var_map(func, var):
     return func(var)
 
 
+def _get_concrete_sequence_fullhash(seq, seen):
+  if seen is None:
+    seen = set()
+  elif id(seq) in seen:
+    return seq.get_default_fullhash()
+  seen.add(id(seq))
+  return hash((type(seq),) +
+              tuple(abstract_utils.get_var_fullhash_component(var, seen)
+                    for var in seq.pyval))
+
+
 class LazyConcreteDict(
     _instance_base.SimpleValue, mixin.PythonConstant, mixin.LazyMembers):
   """Dictionary with lazy values."""
@@ -47,6 +57,9 @@ class ConcreteValue(_instance_base.Instance, mixin.PythonConstant):
     super().__init__(cls, ctx)
     mixin.PythonConstant.init_mixin(self, pyval)
 
+  def get_fullhash(self, seen=None):
+    return hash((type(self), id(self.pyval)))
+
 
 class Module(_instance_base.Instance, mixin.LazyMembers):
   """Represents an (imported) module."""
@@ -123,13 +136,9 @@ class Module(_instance_base.Instance, mixin.LazyMembers):
       self.load_lazy_attribute(name)
     return list(self.members.items())
 
-  def get_fullhash(self):
+  def get_fullhash(self, seen=None):
     """Hash the set of member names."""
-    m = hashlib.md5()
-    m.update(self.full_name.encode("utf-8"))
-    for k in self._member_map:
-      m.update(k.encode("utf-8"))
-    return m.digest()
+    return hash((type(self), self.full_name) + tuple(sorted(self._member_map)))
 
 
 class Coroutine(_instance_base.Instance):
@@ -163,7 +172,7 @@ class Iterator(_instance_base.Instance, mixin.HasSlots):
   def __init__(self, ctx, return_var):
     super().__init__(ctx.convert.iterator_type, ctx)
     mixin.HasSlots.init_mixin(self)
-    self.set_slot("__next__", self.next_slot)
+    self.set_native_slot("__next__", self.next_slot)
     self._return_var = return_var
 
   def next_slot(self, node):
@@ -303,6 +312,9 @@ class Tuple(_instance_base.Instance, mixin.PythonConstant):
                         tuple(approximate_hash(e) for e in self.pyval))
     return self._hash
 
+  def get_fullhash(self, seen=None):
+    return _get_concrete_sequence_fullhash(self, seen)
+
 
 class List(_instance_base.Instance, mixin.HasSlots, mixin.PythonConstant):  # pytype: disable=signature-mismatch
   """Representation of Python 'list' objects."""
@@ -315,8 +327,8 @@ class List(_instance_base.Instance, mixin.HasSlots, mixin.PythonConstant):  # py
     combined_content = ctx.convert.build_content(content)
     self.merge_instance_type_parameter(None, abstract_utils.T, combined_content)
     self.could_contain_anything = False
-    self.set_slot("__getitem__", self.getitem_slot)
-    self.set_slot("__getslice__", self.getslice_slot)
+    self.set_native_slot("__getitem__", self.getitem_slot)
+    self.set_native_slot("__getslice__", self.getslice_slot)
 
   def str_of_constant(self, printer):
     return "[%s]" % ", ".join(" or ".join(_var_map(printer, val))
@@ -328,6 +340,11 @@ class List(_instance_base.Instance, mixin.HasSlots, mixin.PythonConstant):  # py
     else:
       return mixin.PythonConstant.__repr__(self)
 
+  def get_fullhash(self, seen=None):
+    if self.could_contain_anything:
+      return super().get_fullhash(seen)
+    return _get_concrete_sequence_fullhash(self, seen)
+
   def merge_instance_type_parameter(self, node, name, value):
     self.could_contain_anything = True
     super().merge_instance_type_parameter(node, name, value)
@@ -429,12 +446,12 @@ class Dict(_instance_base.Instance, mixin.HasSlots, mixin.PythonDict):
   def __init__(self, ctx):
     super().__init__(ctx.convert.dict_type, ctx)
     mixin.HasSlots.init_mixin(self)
-    self.set_slot("__contains__", self.contains_slot)
-    self.set_slot("__getitem__", self.getitem_slot)
-    self.set_slot("__setitem__", self.setitem_slot)
-    self.set_slot("pop", self.pop_slot)
-    self.set_slot("setdefault", self.setdefault_slot)
-    self.set_slot("update", self.update_slot)
+    self.set_native_slot("__contains__", self.contains_slot)
+    self.set_native_slot("__getitem__", self.getitem_slot)
+    self.set_native_slot("__setitem__", self.setitem_slot)
+    self.set_native_slot("pop", self.pop_slot)
+    self.set_native_slot("setdefault", self.setdefault_slot)
+    self.set_native_slot("update", self.update_slot)
     self.could_contain_anything = False
     # Insertion order does matter in some places.
     # For example: f_locals["__annotations__"]
@@ -456,6 +473,17 @@ class Dict(_instance_base.Instance, mixin.HasSlots, mixin.PythonDict):
     else:
       return mixin.PythonConstant.__repr__(self)
 
+  def get_fullhash(self, seen=None):
+    if self.could_contain_anything:
+      return super().get_fullhash(seen)
+    if seen is None:
+      seen = set()
+    elif id(self) in seen:
+      return self.get_default_fullhash()
+    seen.add(id(self))
+    return hash((type(self),) + abstract_utils.get_dict_fullhash_component(
+        self.pyval, seen=seen))
+
   def getitem_slot(self, node, name_var):
     """Implements the __getitem__ slot."""
     results = []
