@@ -91,6 +91,8 @@ class AbstractAttributeHandler(utils.ContextWeakrefMixin):
       results = []
       nodes = []
       for b in param_var.bindings:
+        if b.data is obj:
+          continue
         node2, ret = self.get_attribute(node, b.data, name, valself)
         if ret is None:
           if b.IsVisible(node):
@@ -504,7 +506,8 @@ class AbstractAttributeHandler(utils.ContextWeakrefMixin):
       elif isinstance(valself.data, abstract.Instance):
         # We need to rebind the parameter values at the root because that's the
         # node at which load_lazy_attribute() converts pyvals.
-        subst = datatypes.AliasingDict()
+        subst = datatypes.AliasingDict(
+            aliases=valself.data.instance_type_parameters.aliases)
         for k, v in valself.data.instance_type_parameters.items():
           if v.bindings:
             subst[k] = self.ctx.program.NewVariable(
@@ -516,7 +519,6 @@ class AbstractAttributeHandler(utils.ContextWeakrefMixin):
             #   class Child(Base): ...  # equivalent to `class Child(Base[Any])`
             # When this happens, parameter values are implicitly set to Any.
             subst[k] = self.ctx.new_unsolvable(self.ctx.root_node)
-        subst.uf = valself.data.instance_type_parameters.uf
       else:
         subst = None
       member = obj.load_lazy_attribute(name, subst)
@@ -533,6 +535,10 @@ class AbstractAttributeHandler(utils.ContextWeakrefMixin):
 
     # Retrieve member
     if name in obj.members and obj.members[name].Bindings(node):
+      # A retrieved attribute may be later mutated; we have no way of tracking
+      # this. Forcibly clear obj's hash and type key caches so that attribute
+      # changes are detected.
+      obj.update_caches(force=True)
       return node, obj.members[name]
     return node, None
 
