@@ -236,12 +236,8 @@ _OPT_IN_FEATURES = [
 FEATURE_FLAGS = [
     _flag("--always-use-return-annotations", False,
           "Always use function return type annotations."),
-    _flag("--overriding-default-value-checks", True,
-          "Enable default value checks for overriding methods."),
     _flag("--overriding-parameter-count-checks", False,
           "Enable parameter count checks for overriding methods."),
-    _flag("--overriding-parameter-name-checks", True,
-          "Enable parameter name checks for overriding methods."),
     _flag("--overriding-return-type-checks", False,
           "Enable return type checks for overriding methods."),
     _flag("--use-enum-overlay", False,
