@@ -73,12 +73,17 @@ class Context:
         # boolean values.
         "True": self.convert.true,
         "False": self.convert.false,
-        # builtin classes
-        "property": special_builtins.Property(self),
-        "staticmethod": special_builtins.StaticMethod(self),
-        "classmethod": special_builtins.ClassMethod(self),
-        "dict": special_builtins.Dict(self),
     }
+    # builtin classes
+    for cls in (
+        special_builtins.ClassMethod,
+        special_builtins.Dict,
+        special_builtins.Property,
+        special_builtins.StaticMethod,
+        special_builtins.Type,
+    ):
+      instance = cls(self)
+      self.special_builtins[instance.name] = instance
     # builtin functions
     for cls in (
         special_builtins.Abs,
@@ -133,11 +138,6 @@ class Context:
   def join_bindings(self, node, bindings):
     return cfg_utils.merge_bindings(self.program, node, bindings)
 
-  # TODO(b/202335303): The only reason this method exists is so that
-  # abstract/mixin.py can construct an abstract.NativeFunction.
-  def make_native_function(self, name, method):
-    return abstract.NativeFunction(name, method, self)
-
   def make_class(self, node, props):
     return vm_utils.make_class(node, props, self)
 
