@@ -6,6 +6,7 @@ import types
 
 from pytype import file_utils
 from pytype.platform_utils import path_utils
+from pytype.tests import test_utils
 from pytype.tools.analyze_project import config
 from pytype.tools.analyze_project import parse_args
 
@@ -59,7 +60,7 @@ class TestFileConfig(TestBase):
   """Test FileConfig."""
 
   def test_config_file(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('test.cfg', PYTYPE_CFG)
       conf = config.FileConfig()
       path = conf.read_from_file(f)
@@ -67,7 +68,7 @@ class TestFileConfig(TestBase):
       self._validate_file_contents(conf, d.path)
 
   def test_missing_config_file_section(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('test.cfg', RANDOM_CFG)
       conf = config.FileConfig()
       path = conf.read_from_file(f)
@@ -83,7 +84,7 @@ class TestFileConfig(TestBase):
 
   def test_read_bad_format(self):
     conf = config.FileConfig()
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('test.cfg', 'ladadeda := squirrels')
       self.assertIsNone(conf.read_from_file(f))
     self._validate_empty_contents(conf)
@@ -133,14 +134,14 @@ class TestGenerateConfig(unittest.TestCase):
           self.parser.pytype_single_args)
 
   def test_existing_file(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('sample.cfg')
       with self.assertRaises(SystemExit):
         config.generate_sample_config_or_die(f, self.parser.pytype_single_args)
 
   def test_generate(self):
     conf = config.FileConfig()
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = path_utils.join(d.path, 'sample.cfg')
       config.generate_sample_config_or_die(f, self.parser.pytype_single_args)
       # Test that we've generated a valid config and spot-check a pytype-all
@@ -158,17 +159,18 @@ class TestGenerateConfig(unittest.TestCase):
                        '{}.{}'.format(*sys.version_info[:2]))
 
   def test_read(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = path_utils.join(d.path, 'test.cfg')
       config.generate_sample_config_or_die(f, self.parser.pytype_single_args)
       conf = config.read_config_file_or_die(f)
-    # Smoke test for postprocessing and spot-check of a result.
-    self.parser.postprocess(conf, from_strings=True)
+    # Smoke test and spot check for string conversion and postprocessing
+    self.parser.convert_strings(conf)
+    self.parser.postprocess(conf)
     self.assertIsInstance(conf.report_errors, bool)
 
   def test_keep_going_file_default(self):
     conf = config.FileConfig()
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = path_utils.join(d.path, 'sample.cfg')
       config.generate_sample_config_or_die(f, self.parser.pytype_single_args)
       conf.read_from_file(f)
@@ -179,26 +181,26 @@ class TestReadConfig(TestBase):
   """Test config.read_config_file_or_die()."""
 
   def test_config_file(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('test.cfg', PYTYPE_CFG)
       conf = config.read_config_file_or_die(f)
       self._validate_file_contents(conf, d.path)
 
   def test_missing_config_file_section(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       f = d.create_file('test.cfg', RANDOM_CFG)
       with self.assertRaises(SystemExit):
         config.read_config_file_or_die(f)
 
   def test_setup_cfg(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       d.create_file('setup.cfg', SETUP_CFG)
       with file_utils.cd(d.path):
         conf = config.read_config_file_or_die(None)
         self._validate_file_contents(conf, d.path)
 
   def test_setup_cfg_from_subdir(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       d.create_file('setup.cfg', SETUP_CFG)
       sub = d.create_directory(file_utils.replace_separator('x/y/z'))
       conf = config.Config()
@@ -207,7 +209,7 @@ class TestReadConfig(TestBase):
         self._validate_file_contents(conf, d.path)
 
   def test_missing_setup_cfg_section(self):
-    with file_utils.Tempdir() as d:
+    with test_utils.Tempdir() as d:
       d.create_file('setup.cfg', RANDOM_CFG)
       with file_utils.cd(d.path):
         conf = config.read_config_file_or_die(None)
